@@ -1,6 +1,6 @@
 var blockinterleaver__xx_8h =
 [
-    [ "gr::blocks::blockinterleaver_xx< T >", "classgr_1_1blocks_1_1blockinterleaver__xx.html", "classgr_1_1blocks_1_1blockinterleaver__xx" ],
+    [ "gr::blocks::blockinterleaver_xx&lt; T &gt;", "classgr_1_1blocks_1_1blockinterleaver__xx.html", "classgr_1_1blocks_1_1blockinterleaver__xx" ],
     [ "gr::blocks::blockinterleaver_bb", "namespacegr_1_1blocks.html#a59de5ff12381ea6ea2cf4cc6f88befe8", null ],
     [ "gr::blocks::blockinterleaver_cc", "namespacegr_1_1blocks.html#a92545f9390e438079b540545ce228944", null ],
     [ "gr::blocks::blockinterleaver_ff", "namespacegr_1_1blocks.html#ab3f1692adc45fc7079f71689697302e4", null ],
