@@ -1,5 +1,8 @@
 var NAVTREEINDEX53 =
 {
+"functions_type_t.html":[5,3,3,9],
+"functions_u.html":[5,3,0,21],
+"functions_v.html":[5,3,0,22],
 "functions_vars.html":[5,3,2],
 "functions_vars.html":[5,3,2,0],
 "functions_vars_a.html":[5,3,2,1],
@@ -246,8 +249,5 @@ var NAVTREEINDEX53 =
 "globals_defs_v.html":[6,1,6,14],
 "globals_defs_w.html":[6,1,6,15],
 "globals_defs_z.html":[6,1,6,16],
-"globals_e.html":[6,1,0,5],
-"globals_enum.html":[6,1,4],
-"globals_eval.html":[6,1,5],
-"globals_f.html":[6,1,0,6]
+"globals_e.html":[6,1,0,5]
 };
