@@ -1,5 +1,8 @@
 var NAVTREEINDEX66 =
 {
+"peak__detector2__fb__pydoc__template_8h.html#a8506517faa0390156214845c79824486":[6,0,9,2,0,0,0,95,7],
+"peak__detector2__fb__pydoc__template_8h.html#ab622dad987e2a660e98968ea860bd570":[6,0,9,2,0,0,0,95,4],
+"peak__detector2__fb__pydoc__template_8h.html#ab8b318b9da474c27b221db6d6c4bf926":[6,0,9,2,0,0,0,95,2],
 "peak__detector2__fb__pydoc__template_8h.html#ac28e256fa6638c67048f53d2e3873e9c":[6,0,9,2,0,0,0,95,9],
 "peak__detector2__fb__pydoc__template_8h.html#ac49d4d4f009fd5da3e5f4a150f8f9770":[6,0,9,2,0,0,0,95,1],
 "peak__detector2__fb__pydoc__template_8h_source.html":[6,0,9,2,0,0,0,95],
@@ -246,8 +249,5 @@ var NAVTREEINDEX66 =
 "pfb__synthesizer__ccf__pydoc__template_8h.html#a6731418e64e123fdfc8a7dbce4d28e36":[6,0,21,2,0,0,0,36,4],
 "pfb__synthesizer__ccf__pydoc__template_8h.html#a74021f021dcdfbb22891787b79c5529d":[6,0,21,2,0,0,0,36,0],
 "pfb__synthesizer__ccf__pydoc__template_8h.html#a777d3a0351c6eac0da73eff4832f95af":[6,0,21,2,0,0,0,36,9],
-"pfb__synthesizer__ccf__pydoc__template_8h.html#a7de6e849a561e0a629d2fb466fab2784":[6,0,21,2,0,0,0,36,2],
-"pfb__synthesizer__ccf__pydoc__template_8h.html#aaad4de24f87a752a42fdb090f5b01eff":[6,0,21,2,0,0,0,36,8],
-"pfb__synthesizer__ccf__pydoc__template_8h.html#ae999482725868120145905ba7e3a2f39":[6,0,21,2,0,0,0,36,7],
-"pfb__synthesizer__ccf__pydoc__template_8h_source.html":[6,0,21,2,0,0,0,36]
+"pfb__synthesizer__ccf__pydoc__template_8h.html#a7de6e849a561e0a629d2fb466fab2784":[6,0,21,2,0,0,0,36,2]
 };
