@@ -1,6 +1,6 @@
 var tsb__vector__sink_8h =
 [
-    [ "gr::blocks::tsb_vector_sink< T >", "classgr_1_1blocks_1_1tsb__vector__sink.html", "classgr_1_1blocks_1_1tsb__vector__sink" ],
+    [ "gr::blocks::tsb_vector_sink&lt; T &gt;", "classgr_1_1blocks_1_1tsb__vector__sink.html", "classgr_1_1blocks_1_1tsb__vector__sink" ],
     [ "gr::blocks::tsb_vector_sink_b", "namespacegr_1_1blocks.html#a5a6348a1891561547903d248812d362f", null ],
     [ "gr::blocks::tsb_vector_sink_c", "namespacegr_1_1blocks.html#a176c0c819725a73914eb3a1803467bc6", null ],
     [ "gr::blocks::tsb_vector_sink_f", "namespacegr_1_1blocks.html#a174b51b363824a8cff75a80c6cead819", null ],
